pub struct Record {Show 17 fields
pub code: Code,
pub operating_code: Code,
pub kind: Kind,
pub name: &'static str,
pub legal_entity_name: Option<&'static str>,
pub legal_entity_id: Option<&'static lei>,
pub category: Category,
pub acronym: Option<&'static str>,
pub country: Alpha2,
pub city: &'static str,
pub website: Option<&'static str>,
pub status: Status,
pub creation_date: NaiveDate,
pub last_update_date: NaiveDate,
pub last_validation_date: Option<NaiveDate>,
pub expiry_date: Option<NaiveDate>,
pub comments: Option<&'static str>,
}Expand description
All data about a MIC.
Fields
code: CodeThe market identifier code.
operating_code: CodeThe code of the operating entity.
kind: KindThe type of code.
name: &'static strThe name of the operating entity.
legal_entity_name: Option<&'static str>The name of the legal entity.
legal_entity_id: Option<&'static lei>The legal entity ID.
category: CategoryThe market category this code is operating in.
acronym: Option<&'static str>The known acronym of the code.
country: Alpha2The Alpha2 country code the organization operating this code is registered in.
city: &'static strThe city the organization operating this code is registered in.
website: Option<&'static str>The website of the organization operating this code.
status: StatusThe status of this code.
creation_date: NaiveDateThe date this record was created at.
last_update_date: NaiveDateThe date this record was updated at.
last_validation_date: Option<NaiveDate>The date this record was last validated.
expiry_date: Option<NaiveDate>The date this record was marked expired.
comments: Option<&'static str>Any comments about this record.